/**
 * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'placeholder', 'lv', {
	title: 'Viettura uzstādījumi',
	toolbar: 'Izveidot vietturi',
	name: 'Viettura nosaukums',
	invalidName: 'Vietturis nevar būt tukšs un nevar saturēt simbolus [, ], <, >',
	pathName: 'vietturis'
} );
